@@ -82,12 +82,14 @@ class Browser extends AbstractClientParser
         '4A' => 'Acoo Browser',
         'BW' => 'AdBlock Browser',
         'A7' => 'Adult Browser',
+        '8A' => 'Ai Browser',
         'A9' => 'Airfind Secure Browser',
         'AF' => 'ANT Fresco',
         'AG' => 'ANTGalio',
         'AL' => 'Aloha Browser',
         'AH' => 'Aloha Browser Lite',
         'A8' => 'ALVA',
+        '9A' => 'AltiBrowser',
         'AM' => 'Amaya',
         'A3' => 'Amaze Browser',
         'A5' => 'Amerigo',
@@ -99,6 +101,7 @@ class Browser extends AbstractClientParser
         'A4' => 'AOL Shield Pro',
         '2A' => 'Aplix',
         'A6' => 'AppBrowzer',
+        '0A' => 'AppTec Secure Browser',
         'AP' => 'APUS Browser',
         'AR' => 'Arora',
         'AX' => 'Arctic Fox',
@@ -106,7 +109,8 @@ class Browser extends AbstractClientParser
         'AW' => 'Amiga Aweb',
         'PN' => 'APN Browser',
         '6A' => 'Arachne',
-        'RA' => 'Arc',
+        'RA' => 'Arc Search',
+        'R5' => 'Armorfly Browser',
         'AI' => 'Arvin',
         'AK' => 'Ask.com',
         'AU' => 'Asus Browser',
@@ -117,6 +121,7 @@ class Browser extends AbstractClientParser
         'VG' => 'AVG Secure Browser',
         'AC' => 'Avira Secure Browser',
         'A1' => 'AwoX',
+        '7A' => 'Awesomium',
         '5B' => 'Basic Web Browser',
         'BA' => 'Beaker Browser',
         'BM' => 'Beamrise',
@@ -151,6 +156,7 @@ class Browser extends AbstractClientParser
         'BX' => 'BrowseX',
         'BZ' => 'Browzar',
         'B7' => 'Browlser',
+        'M9' => 'Browser Mini',
         '4B' => 'BrowsBit',
         'BY' => 'Biyubi',
         'BF' => 'Byffox',
@@ -195,6 +201,7 @@ class Browser extends AbstractClientParser
         'C5' => 'Chromium GOST',
         'CY' => 'Cyberfox',
         'CS' => 'Cheshire',
+        '8C' => 'Cromite',
         'RC' => 'Crow Browser',
         'CT' => 'Crusta',
         'CG' => 'Craving Explorer',
@@ -267,6 +274,7 @@ class Browser extends AbstractClientParser
         'FH' => 'Flash Browser',
         'FS' => 'Flast',
         'F5' => 'Flyperlink',
+        'F9' => 'FOSS Browser',
         'FU' => 'FreeU',
         'F6' => 'Freedom Browser',
         'FT' => 'Frost',
@@ -287,17 +295,20 @@ class Browser extends AbstractClientParser
         'G2' => 'GO Browser',
         'RN' => 'GreenBrowser',
         'HW' => 'Habit Browser',
+        'H7' => 'Halo Browser',
         'HB' => 'Harman Browser',
         'HS' => 'HasBrowser',
         'HA' => 'Hawk Turbo Browser',
         'HQ' => 'Hawk Quick Browser',
         'HE' => 'Helio',
+        'HN' => 'Herond Browser',
         'HX' => 'Hexa Web Browser',
         'HI' => 'Hi Browser',
         'HO' => 'hola! Browser',
         'H4' => 'Holla Web Browser',
         'H5' => 'HotBrowser',
         'HJ' => 'HotJava',
+        'H6' => 'HONOR Browser',
         'HT' => 'HTC Browser',
         'HU' => 'Huawei Browser Mobile',
         'HP' => 'Huawei Browser',
@@ -308,6 +319,7 @@ class Browser extends AbstractClientParser
         'I6' => 'iDesktop PC Browser',
         'IC' => 'iCab',
         'I2' => 'iCab Mobile',
+        '4I' => 'iNet Browser',
         'I1' => 'Iridium',
         'I3' => 'Iron Mobile',
         'I4' => 'IceCat',
@@ -321,6 +333,7 @@ class Browser extends AbstractClientParser
         'I9' => 'Insta Browser',
         'IE' => 'Internet Explorer',
         'I7' => 'Internet Browser Secure',
+        '5I' => 'Internet Webbrowser',
         '3I' => 'Intune Managed Browser',
         'I5' => 'Indian UC Mini Browser',
         'Z0' => 'InBrowser',
@@ -337,6 +350,7 @@ class Browser extends AbstractClientParser
         'JZ' => 'JUZI Browser',
         'KB' => 'K.Browser',
         'KF' => 'Keepsafe Browser',
+        'K7' => 'KeepSolid Browser',
         'KS' => 'Kids Safe Browser',
         'KI' => 'Kindle Browser',
         'KM' => 'K-meleon',
@@ -348,6 +362,7 @@ class Browser extends AbstractClientParser
         'K4' => 'Kitt',
         'KW' => 'Kiwi',
         'KD' => 'Kode Browser',
+        'KU' => 'KUN',
         'KT' => 'KUTO Mini Browser',
         'KY' => 'Kylo',
         'KZ' => 'Kazehakase',
@@ -377,6 +392,7 @@ class Browser extends AbstractClientParser
         'LX' => 'Lynx',
         'L2' => 'Lynket Browser',
         'MD' => 'Mandarin',
+        'MP' => 'Maple',
         'M5' => 'MarsLab Web Browser',
         'M7' => 'MaxBrowser',
         'M1' => 'mCent',
@@ -390,14 +406,16 @@ class Browser extends AbstractClientParser
         'M3' => 'Midori Lite',
         'M6' => 'MixerBox AI',
         'MO' => 'Mobicip',
-        'MU' => 'MIUI Browser',
+        'MU' => 'Mi Browser',
         'MS' => 'Mobile Silk',
         'MK' => 'Mogok Browser',
+        'M8' => 'Motorola Internet Browser',
         'MN' => 'Minimo',
         'MT' => 'Mint Browser',
         'MX' => 'Maxthon',
         'M4' => 'MaxTube Browser',
         'MA' => 'Maelstrom',
+        '3M' => 'Mises',
         'MM' => 'Mmx Browser',
         'NM' => 'MxNitro',
         'MY' => 'Mypal',
@@ -422,6 +440,7 @@ class Browser extends AbstractClientParser
         'NP' => 'NetPositive',
         'NS' => 'Netscape',
         'WR' => 'NextWord Browser',
+        'N8' => 'Ninesky',
         'NT' => 'NTENT Browser',
         'NU' => 'Nuanti Meta',
         'NI' => 'Nuviu',
@@ -440,6 +459,7 @@ class Browser extends AbstractClientParser
         'OL' => 'OnBrowser Lite',
         'OE' => 'ONE Browser',
         'N4' => 'Onion Browser',
+        '1N' => 'ONIONBrowser',
         'Y1' => 'Opera Crypto',
         'OX' => 'Opera GX',
         'OG' => 'Opera Neon',
@@ -461,27 +481,35 @@ class Browser extends AbstractClientParser
         'O4' => 'Open Browser',
         '4U' => 'Open Browser 4U',
         '5G' => 'Open Browser fast 5G',
+        '5O' => 'Open Browser Lite',
         'O7' => 'Open TV Browser',
         'OW' => 'OmniWeb',
         'OT' => 'Otter Browser',
         '4O' => 'Owl Browser',
+        'JR' => 'OJR Browser',
         'PL' => 'Palm Blazer',
         'PM' => 'Pale Moon',
         'PY' => 'Polypane',
+        '8P' => 'Prism',
         'PP' => 'Oppo Browser',
         'P6' => 'Opus Browser',
         'PR' => 'Palm Pre',
-        'PU' => 'Puffin',
+        '7I' => 'Puffin Cloud Browser',
+        '6I' => 'Puffin Incognito Browser',
+        'PU' => 'Puffin Secure Browser',
         '2P' => 'Puffin Web Browser',
         'PW' => 'Palm WebPro',
         'PA' => 'Palmscape',
         'P7' => 'Pawxy',
+        '0P' => 'Peach Browser',
         'PE' => 'Perfect Browser',
+        'K6' => 'Perk',
         'P1' => 'Phantom.me',
         'PH' => 'Phantom Browser',
         'PX' => 'Phoenix',
         'PB' => 'Phoenix Browser',
         '5P' => 'Photon',
+        'N9' => 'Pintar Browser',
         'P9' => 'PirateBrowser',
         'P8' => 'PICO Browser',
         'PF' => 'PlayFree Browser',
@@ -489,16 +517,22 @@ class Browser extends AbstractClientParser
         'PO' => 'Polaris',
         'PT' => 'Polarity',
         'LY' => 'PolyBrowser',
+        '9P' => 'Presearch',
+        'BP' => 'Privacy Browser',
         'PI' => 'PrivacyWall',
         'P4' => 'Privacy Explorer Fast Safe',
+        'X5' => 'Privacy Pioneer Browser',
         'P3' => 'Private Internet Browser',
         'P5' => 'Proxy Browser',
         '7P' => 'Proxyium',
         '6P' => 'Proxynet',
+        '2F' => 'ProxyFox',
+        '2M' => 'ProxyMax',
         'P2' => 'Pi Browser',
         'P0' => 'PronHub Browser',
         'PC' => 'PSI Secure Browser',
         'RW' => 'Reqwireless WebViewer',
+        'RO' => 'Roccat',
         'PS' => 'Microsoft Edge',
         'QA' => 'Qazweb',
         'QI' => 'Qiyu',
@@ -513,10 +547,12 @@ class Browser extends AbstractClientParser
         'QU' => 'Quark',
         'QZ' => 'QupZilla',
         'QM' => 'Qwant Mobile',
+        'Q5' => 'QtWeb',
         'QW' => 'QtWebEngine',
         'R3' => 'Rakuten Browser',
         'R4' => 'Rakuten Web Search',
         'R2' => 'Raspbian Chromium',
+        'RT' => 'RCA Tor Explorer',
         'RE' => 'Realme Browser',
         'RK' => 'Rekonq',
         'RM' => 'RockMelt',
@@ -544,6 +580,7 @@ class Browser extends AbstractClientParser
         'K1' => 'Sidekick',
         'S1' => 'SimpleBrowser',
         '3S' => 'SilverMob US',
+        'ZB' => 'Singlebox',
         'SY' => 'Sizzy',
         'K3' => 'Skye',
         'SK' => 'Skyfire',
@@ -564,6 +601,7 @@ class Browser extends AbstractClientParser
         'LE' => 'Smart Lenovo Browser',
         'OZ' => 'Smooz',
         'SN' => 'Snowshoe',
+        'K5' => 'Spark',
         'B1' => 'Spectre Browser',
         'S2' => 'Splash',
         'SI' => 'Sputnik Browser',
@@ -582,6 +620,7 @@ class Browser extends AbstractClientParser
         'S4' => 'Steam In-Game Overlay',
         'ST' => 'Streamy',
         'SX' => 'Swiftfox',
+        'W7' => 'Swiftweasel',
         'SZ' => 'Seznam Browser',
         'W1' => 'Sweet Browser',
         '2X' => 'SX Browser',
@@ -600,10 +639,14 @@ class Browser extends AbstractClientParser
         'TI' => 'Tint Browser',
         'TL' => 'TrueLocation Browser',
         'TC' => 'TUC Mini Browser',
+        'TK' => 'TUSK',
         'TU' => 'Tungsten',
         'TG' => 'ToGate',
+        'T3' => 'Total Browser',
+        'TQ' => 'TQ Browser',
         'TS' => 'TweakStyle',
         'TV' => 'TV Bro',
+        'T4' => 'TV-Browser Internet',
         'U0' => 'U Browser',
         'UB' => 'UBrowser',
         'UC' => 'UC Browser',
@@ -611,12 +654,14 @@ class Browser extends AbstractClientParser
         'UM' => 'UC Browser Mini',
         'UT' => 'UC Browser Turbo',
         'UI' => 'Ui Browser Mini',
+        'UP' => 'UPhone Browser',
         'UR' => 'UR Browser',
         'UZ' => 'Uzbl',
         'UE' => 'Ume Browser',
         'V0' => 'vBrowser',
         'VA' => 'Vast Browser',
         'V3' => 'VD Browser',
+        'VR' => 'Veera',
         'VE' => 'Venus Browser',
         'WD' => 'Vewd Browser',
         'V5' => 'VibeMate',
@@ -628,6 +673,7 @@ class Browser extends AbstractClientParser
         'VB' => 'Vision Mobile Browser',
         'V4' => 'Vertex Surf',
         'VM' => 'VMware AirWatch',
+        'V6' => 'VMS Mosaic',
         'VK' => 'Vonkeror',
         'VU' => 'Vuhuv',
         'WI' => 'Wear Internet Browser',
@@ -642,15 +688,18 @@ class Browser extends AbstractClientParser
         'WB' => 'Wave Browser',
         'WA' => 'Wavebox',
         'WH' => 'Whale Browser',
+        'W2' => 'Whale TV Browser',
         'WO' => 'wOSBrowser',
         '3W' => 'w3m',
         'WT' => 'WeTab Browser',
         '1W' => 'World Browser',
         'WL' => 'Wolvic',
+        'WK' => 'Wukong Browser',
         'WY' => 'Wyzo',
         'YG' => 'YAGI',
         'YJ' => 'Yahoo! Japan Browser',
         'YA' => 'Yandex Browser',
+        'Y4' => 'Yandex Browser Corp',
         'YL' => 'Yandex Browser Lite',
         'YN' => 'Yaani Browser',
         'Y2' => 'Yo Browser',
@@ -659,6 +708,7 @@ class Browser extends AbstractClientParser
         'Y3' => 'YouBrowser',
         'YZ' => 'Yuzu Browser',
         'XR' => 'xBrowser',
+        'X3' => 'MMBOX XBrowser',
         'XB' => 'X Browser Lite',
         'X0' => 'X-VPN',
         'X1' => 'xBrowser Pro Super Fast',
@@ -666,12 +716,14 @@ class Browser extends AbstractClientParser
         'XT' => 'XtremeCast',
         'XS' => 'xStand',
         'XI' => 'Xiino',
+        'X4' => 'XnBrowse',
         'XO' => 'Xooloo Internet',
         'XV' => 'Xvast',
         'ZE' => 'Zetakey',
         'ZV' => 'Zvu',
         'ZI' => 'Zirco Browser',
         'ZR' => 'Zordo Browser',
+        'ZT' => 'ZTE Browser',
 
         // detected browsers in older versions
         // 'IA' => 'Iceape',  => pim
@@ -684,9 +736,9 @@ class Browser extends AbstractClientParser
      * @var array
      */
     protected static $browserFamilies = [
-        'Android Browser'    => ['AN', 'MU'],
+        'Android Browser'    => ['AN'],
         'BlackBerry Browser' => ['BB'],
-        'Baidu'              => ['BD', 'BS'],
+        'Baidu'              => ['BD', 'BS', 'H6'],
         'Amiga'              => ['AV', 'AW'],
         'Chrome'             => [
             'CH', '2B', '7S', 'A0', 'AC', 'A4', 'AE', 'AH', 'AI',
@@ -717,15 +769,19 @@ class Browser extends AbstractClientParser
             'N3', 'GD', 'O9', 'Q3', 'F7', 'K2', 'P5', 'H5', 'V3',
             'K3', 'Q4', 'G2', 'R2', 'WX', 'XP', '3I', 'BG', 'R0',
             'JO', 'OL', 'GN', 'W4', 'QI', 'E1', 'RI', '8B', '5B',
-            'K4',
+            'K4', 'WK', 'T3', 'K5', 'MU', '9P', 'K6', 'VR', 'N9',
+            'M9', 'F9', '0P', '0A', 'JR', 'D3', 'TK', 'BP', '2F',
+            '2M', 'K7', '1N', '8A', 'H7', 'X3', 'T4', 'X4', '5O',
+            '8C', '3M', '6I', '2P', 'PU', '7I', 'X5', 'AL', '3P',
+            'W2', 'ZB', 'HN',
         ],
         'Firefox'            => [
             'FF', 'BI', 'BF', 'BH', 'BN', 'C0', 'CU', 'EI', 'F1',
-            'FB', 'FE', 'AX', 'FM', 'FR', 'FY', 'GZ', 'I4', 'IF',
+            'FB', 'FE', 'AX', 'FM', 'FR', 'FY', 'I4', 'IF', '8P',
             'IW', 'LH', 'LY', 'MB', 'MN', 'MO', 'MY', 'OA', 'OS',
             'PI', 'PX', 'QA', 'S5', 'SX', 'TF', 'TO', 'WF', 'ZV',
-            'FP', 'AD', 'WL', '2I', 'P9', 'KJ', 'WY', 'VK', 'W5',
-            '7C', 'N7',
+            'FP', 'AD', '2I', 'P9', 'KJ', 'WY', 'VK', 'W5',
+            '7C', 'N7', 'W7',
         ],
         'Internet Explorer'  => ['IE', 'CZ', 'BZ', 'IM', 'PS', '3A', '4A', 'RN'],
         'Konqueror'          => ['KO'],
@@ -744,9 +800,9 @@ class Browser extends AbstractClientParser
      */
     protected static $mobileOnlyBrowsers = [
         '36', 'AH', 'AI', 'BL', 'C1', 'C4', 'CB', 'CW', 'DB',
-        'DD', 'DT', 'EU', 'EZ', 'FK', 'FM', 'FR', 'FX', 'GH',
+        '3M', 'DT', 'EU', 'EZ', 'FK', 'FM', 'FR', 'FX', 'GH',
         'GI', 'GR', 'HA', 'HU', 'IV', 'JB', 'KD', 'M1', 'MF',
-        'MN', 'MZ', 'NX', 'OC', 'OI', 'OM', 'OZ', 'PU', 'PI',
+        'MN', 'MZ', 'NX', 'OC', 'OI', 'OM', 'OZ', '2P', 'PI',
         'PE', 'QU', 'RE', 'S0', 'S7', 'SA', 'SB', 'SG', 'SK',
         'ST', 'SU', 'T1', 'UH', 'UM', 'UT', 'VE', 'VV', 'WI',
         'WP', 'YN', 'IO', 'IS', 'HQ', 'RW', 'HI', 'PN', 'BW',
@@ -761,9 +817,12 @@ class Browser extends AbstractClientParser
         'ZR', 'D6', 'F6', 'P3', 'FT', 'A9', 'X2', 'NI', 'FG',
         'TH', 'N3', 'GD', 'O9', 'Q3', 'F7', 'K2', 'N4', 'P5',
         'H5', 'V3', 'G2', 'BG', 'OL', 'II', 'TL', 'M6', 'Y3',
-        'M7', 'GN', 'D3', 'IG', 'HW', '4O', 'OU', '5P', 'KE',
+        'M7', 'GN', 'JR', 'IG', 'HW', '4O', 'OU', '5P', 'KE',
         '5A', 'TT', '6P', 'G3', '7P', 'VU', 'F8', 'L4', 'DK',
-        'DP', 'KL', 'K4', 'N6',
+        'DP', 'KL', 'K4', 'N6', 'KU', 'WK', 'M8', 'UP', 'ZT',
+        '9P', 'N8', 'VR', 'N9', 'M9', 'F9', '0P', '0A', '2F',
+        '2M', 'K7', '1N', '8A', 'H7', 'X3', 'X4', '5O', '6I',
+        '7I', 'X5', '3P',
     ];
 
     /**
@@ -776,6 +835,7 @@ class Browser extends AbstractClientParser
         'Chrome Webview'             => ['Android WebView'],
         'DuckDuckGo Privacy Browser' => ['DuckDuckGo'],
         'Edge WebView'               => ['Microsoft Edge WebView2'],
+        'Mi Browser'                 => ['Miui Browser', 'XiaoMiBrowser'],
         'Microsoft Edge'             => ['Edge'],
         'Norton Private Browser'     => ['Norton Secure Browser'],
         'Vewd Browser'               => ['Vewd Core'],
@@ -936,23 +996,22 @@ class Browser extends AbstractClientParser
                 $engineVersion = $browserFromUserAgent['engine_version'] ?? '';
             }
 
-            if ('Atom' === $name || 'Huawei Browser' === $name) {
+            // If client hints report the following browsers, we use the version from useragent
+            if (!empty($browserFromUserAgent['version'])
+                && \in_array($short, ['A0', 'AL', 'HP', 'JR', 'MU', 'OM', 'OP', 'VR'])
+            ) {
                 $version = $browserFromUserAgent['version'];
             }
 
-            if ('DuckDuckGo Privacy Browser' === $name) {
-                $version = '';
-            }
-
             if ('Vewd Browser' === $name) {
                 $engine        = $browserFromUserAgent['engine'] ?? '';
                 $engineVersion = $browserFromUserAgent['engine_version'] ?? '';
             }
 
             // If client hints report Chromium, but user agent detects a Chromium based browser, we favor this instead
-            if ('Chromium' === $name
+            if (('Chromium' === $name || 'Chrome Webview' === $name)
                 && !empty($browserFromUserAgent['name'])
-                && 'Chromium' !== $browserFromUserAgent['name']
+                && !\in_array($browserFromUserAgent['short_name'], ['CR', 'CV', 'AN'])
             ) {
                 $name    = $browserFromUserAgent['name'];
                 $short   = $browserFromUserAgent['short_name'];
@@ -976,14 +1035,25 @@ class Browser extends AbstractClientParser
             if ($name === $browserFromUserAgent['name']) {
                 $engine        = $browserFromUserAgent['engine'] ?? '';
                 $engineVersion = $browserFromUserAgent['engine_version'] ?? '';
+            }
 
-                // In case the user agent reports a more detailed version, we try to use this instead
-                if (!empty($browserFromUserAgent['version'])
-                    && 0 === \strpos($browserFromUserAgent['version'], $version)
-                    && \version_compare($version, $browserFromUserAgent['version'], '<')
-                ) {
-                    $version = $browserFromUserAgent['version'];
-                }
+            // In case the user agent reports a more detailed version, we try to use this instead
+            if (!empty($browserFromUserAgent['version'])
+                && 0 === \strpos($browserFromUserAgent['version'], $version)
+                && \version_compare($version, $browserFromUserAgent['version'], '<')
+            ) {
+                $version = $browserFromUserAgent['version'];
+            }
+
+            if ('DuckDuckGo Privacy Browser' === $name) {
+                $version = '';
+            }
+
+            // In case client hints report a more detailed engine version, we try to use this instead
+            if ('Blink' === $engine && 'Iridium' !== $name
+                && \version_compare($engineVersion, $browserFromClientHints['version'], '<')
+            ) {
+                $engineVersion = $browserFromClientHints['version'];
             }
         } else {
             $name          = $browserFromUserAgent['name'];
@@ -1017,7 +1087,7 @@ class Browser extends AbstractClientParser
             }
         }
 
-        if (empty($name)) {
+        if (empty($name) || 1 === \preg_match('/Cypress|PhantomJS/', $this->userAgent)) {
             return [];
         }
 
@@ -1033,6 +1103,21 @@ class Browser extends AbstractClientParser
             $engineVersion = '';
         }
 
+        // This browser simulates user-agent of Firefox
+        if ('TV-Browser Internet' === $name && 'Gecko' === $engine) {
+            $family        = 'Chrome';
+            $engine        = 'Blink';
+            $engineVersion = '';
+        }
+
+        if ('Wolvic' === $name && 'Blink' === $engine) {
+            $family = 'Chrome';
+        }
+
+        if ('Wolvic' === $name && 'Gecko' === $engine) {
+            $family = 'Firefox';
+        }
+
         return [
             'type'           => 'browser',
             'name'           => $name,
