@@ -100,12 +100,14 @@ abstract class AbstractDeviceParser extends AbstractParser
         'AE'  => 'Ace',
         'AC'  => 'Acer',
         'ACL' => 'Aceline',
+        'ACP' => 'Acepad',
         '3K'  => 'Acteck',
         'ACT' => 'actiMirror',
         'A9'  => 'Advan',
         'AD'  => 'Advance',
         'ADV' => 'Advantage Air',
         '76'  => 'Adronix',
+        'ADR' => 'Adreamer',
         'AF'  => 'AfriOne',
         'FY'  => 'AFFIX',
         'A3'  => 'AGM',
@@ -128,22 +130,28 @@ abstract class AbstractDeviceParser extends AbstractParser
         'Q3'  => 'AKIRA',
         '1A'  => 'Alba',
         'AL'  => 'Alcatel',
+        'AL0' => 'Alienware',
         '20'  => 'Alcor',
         'XY'  => 'Alps',
         'XYA' => 'XY Auto',
+        'AAU' => 'AAUW',
         '7L'  => 'ALDI NORD',
         '6L'  => 'ALDI SÜD',
         '3L'  => 'Alfawise',
         '4A'  => 'Aligator',
+        'ALS' => 'All Star',
         'AA'  => 'AllCall',
         '3A'  => 'AllDocube',
+        'ALL' => 'allente',
         'A2'  => 'Allview',
         'ALI' => 'ALLINmobile',
         'A7'  => 'Allwinner',
+        'ALP' => 'alpsmart',
         'A1'  => 'Altech UEC',
         '66'  => 'Altice',
         'ALM' => 'Altimo',
         'A5'  => 'altron',
+        'ALB' => 'Altibox',
         'ALT' => 'Altus',
         'KN'  => 'Amazon',
         'AMZ' => 'Amazon Basics',
@@ -155,6 +163,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         '54'  => 'AMCV',
         '60'  => 'Andowl',
         'ANX' => 'ANXONIT',
+        'ANL' => 'ANCEL',
+        'ANC' => 'ANBERNIC',
+        'AND' => 'andersson',
         '6J'  => 'Angelcare',
         'ANG' => 'AngelTech',
         '7A'  => 'Anry',
@@ -166,6 +177,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '55'  => 'AOpen',
         'RW'  => 'Aoro',
         '9Y'  => 'Aocos',
+        'AOW' => 'Aocwei',
         'AP'  => 'Apple',
         'ARC' => 'Arçelik',
         'AR'  => 'Archos',
@@ -182,7 +194,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         '59'  => 'ArtLine',
         '8A'  => 'Asano',
         '90'  => 'Asanzo',
-        '1U'  => 'Astro',
+        '1U'  => 'Astro (UA)',
+        'AST' => 'astro (MY)',
         'A4'  => 'Ask',
         'A8'  => 'Assistant',
         'ASS' => 'ASSE',
@@ -192,10 +205,13 @@ abstract class AbstractDeviceParser extends AbstractParser
         'ATE' => 'Atlantic Electrics',
         '5Q'  => 'Atmaca Elektronik',
         'YH'  => 'ATMAN',
+        'ATM' => 'ATMPC',
         '2A'  => 'Atom',
+        'AT1' => 'Atozee',
         'ATO' => 'ATOL',
         'Z2'  => 'Atvio',
         'ATI' => 'Attila',
+        'ATU' => 'Atouch',
         'AX'  => 'Audiovox',
         'AJ'  => 'AURIS',
         'YZ'  => 'Autan',
@@ -212,6 +228,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'XA'  => 'Axioo',
         'AM'  => 'Azumi Mobile',
         'AZE' => 'Azeyou',
+        'AZU' => 'Azupik',
+        'AZO' => 'AZOM',
         'WW'  => 'Awow',
         'AWO' => 'AWOX',
         'XU'  => 'AUX',
@@ -242,6 +260,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'YB'  => 'Beista',
         'BY'  => 'BS Mobile',
         'BZ'  => 'Bezkam',
+        'BEL' => 'Bell',
         '9B'  => 'Bellphone',
         '63'  => 'Beyond',
         'BG'  => 'BGH',
@@ -255,11 +274,14 @@ abstract class AbstractDeviceParser extends AbstractParser
         'BT'  => 'Bitel',
         'B7'  => 'Bitmore',
         'ZB'  => 'Bittium',
+        'BIE' => 'Biegedy',
         'BK'  => 'Bkav',
         '5B'  => 'Black Bear',
         'BLK' => 'Black Box',
         'BF'  => 'Black Fox',
         'BPC' => 'Blackpcs',
+        'BLP' => 'Blackphone',
+        'BLT' => 'Blackton',
         'B2'  => 'Blackview',
         '2Y'  => 'b2m',
         'BP'  => 'Blaupunkt',
@@ -299,12 +321,17 @@ abstract class AbstractDeviceParser extends AbstractParser
         '4Q'  => 'Bundy',
         'Y8'  => 'Bubblegum',
         'BMW' => 'BMW',
+        'BYJ' => 'BYJU\'S',
+        'BYY' => 'BYYBUO',
+        'BYD' => 'BYD',
         'C9'  => 'CAGI',
         'CAD' => 'CADENA',
         'CT'  => 'Capitel',
+        'GRD' => 'G-Guard',
         'G3'  => 'CG Mobile',
         '37'  => 'CGV',
         'CP'  => 'Captiva',
+        'CPD' => 'CPDEVICE',
         'CF'  => 'Carrefour',
         'CA1' => 'Carbon Mobile',
         'CS'  => 'Casio',
@@ -312,6 +339,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'CA'  => 'Cat',
         'BC'  => 'Camfone',
         'CJ'  => 'Cavion',
+        'CNM' => 'Canaima',
         'CAN' => 'Canal+',
         '4D'  => 'Canal Digital',
         'CNG' => 'Canguro',
@@ -334,6 +362,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'C3'  => 'China Mobile',
         'U9'  => 'China Telecom',
         'CI'  => 'Chico Mobile',
+        'CHC' => 'CHCNAV',
         'CIA' => 'C Idea',
         'CIP' => 'CipherLab',
         'CIT' => 'Citycall',
@@ -350,6 +379,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'CY'  => 'Coby Kyros',
         'XC'  => 'Cobalt',
         'C6'  => 'Comio',
+        'COM' => 'CommScope',
         'CL'  => 'Compal',
         'CQ'  => 'Compaq',
         'C7'  => 'ComTrade Tesla',
@@ -359,12 +389,15 @@ abstract class AbstractDeviceParser extends AbstractParser
         'C5'  => 'Condor',
         'C5M' => 'C5 Mobile',
         '4C'  => 'Conquest',
+        'COG' => 'CONSUNG',
         '3C'  => 'Contixo',
         '8C'  => 'Connex',
         '53'  => 'Connectce',
         'CON' => 'Conceptum',
         'CED' => 'Continental Edison',
         '9C'  => 'Colors',
+        'COL' => 'COLORROOM',
+        'CAA' => 'coocaa',
         'CO'  => 'Coolpad',
         'COO' => 'Coopers',
         'CDE' => 'COOD-E',
@@ -380,6 +413,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'CX'  => 'Crescent',
         'CK'  => 'Cricket',
         'CM'  => 'Crius Mea',
+        'CMF' => 'CMF',
         '0C'  => 'Crony',
         'C1'  => 'Crosscall',
         '4W'  => 'Crown',
@@ -387,8 +421,10 @@ abstract class AbstractDeviceParser extends AbstractParser
         'CU'  => 'Cube',
         'CB'  => 'CUBOT',
         'CUI' => 'Cuiud',
+        'CUL' => 'Cultraview',
         'CV'  => 'CVTE',
         'CWO' => 'Cwowdefu',
+        'CX0' => 'CX',
         'C4'  => 'Cyrus',
         'D5'  => 'Daewoo',
         'DA'  => 'Danew',
@@ -439,12 +475,14 @@ abstract class AbstractDeviceParser extends AbstractParser
         'DIV' => 'DiverMax',
         'D6'  => 'Divisat',
         'DIO' => 'DIORA',
+        'DIF' => 'Diofox',
         'X6'  => 'DIXON',
         'DIM' => 'DIMO',
         '5D'  => 'DING DING',
         'DIN' => 'Dinax',
         'DNA' => 'Dinalink',
         'DM'  => 'DMM',
+        'DMO' => 'DMOAO',
         'DN'  => 'DNS',
         'DC'  => 'DoCoMo',
         'DF'  => 'Doffler',
@@ -457,6 +495,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'DPA' => 'DPA',
         'JQ'  => 'Doppio',
         'DR'  => 'Doro',
+        'DOR' => 'Dora',
         'ZD'  => 'DORLAND',
         'DRO' => 'Droidlogic',
         'D8'  => 'Droxio',
@@ -470,7 +509,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         'UD'  => 'DUNNS Mobile',
         'DUU' => 'Duubee',
         'DUR' => 'Durabook',
+        'DUD' => 'DUDU AUTO',
         'DYO' => 'Dyon',
+        'DYM' => 'Dykemann',
         'DTE' => 'D-Tech',
         'DLI' => 'D-Link',
         'ENO' => 'eNOVA',
@@ -480,9 +521,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'EB'  => 'E-Boda',
         'EJ'  => 'Engel',
         'ENA' => 'ENACOM',
+        'END' => 'ENDURO',
         'ENI' => 'ENIE',
         '2E'  => 'E-Ceros',
         'E8'  => 'E-tel',
+        'ETH' => 'E-TACHI',
         'EAS' => 'EAS Electric',
         'EP'  => 'Easypix',
         'EQ'  => 'Eagle',
@@ -498,6 +541,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'EDE' => 'Edenwood',
         'E6'  => 'EE',
         'GW'  => 'EGL',
+        'EGO' => 'EGOTEK',
         'EFT' => 'EFT',
         'EK'  => 'EKO',
         'EY'  => 'Einstein',
@@ -509,6 +553,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '7E'  => 'ELARI',
         '03'  => 'Electroneum',
         'Z8'  => 'ELECTRONIA',
+        'ELG' => 'ELE-GATE',
         'EL1' => 'Elecson',
         'ELK' => 'Elektroland',
         'L0'  => 'Element',
@@ -516,6 +561,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'EL'  => 'Elephone',
         'JE'  => 'Elekta',
         'ELE' => 'Elevate',
+        'ELS' => 'Elista',
+        'ELT' => 'elit',
         '4E'  => 'Eltex',
         'ELM' => 'Elong Mobile',
         'ED'  => 'Energizer',
@@ -538,16 +585,22 @@ abstract class AbstractDeviceParser extends AbstractParser
         'EN'  => 'Eton',
         'ET'  => 'eTouch',
         '1E'  => 'Etuline',
+        'EHL' => 'Ehlel',
         'EU'  => 'Eurostar',
         '4J'  => 'Eurocase',
+        'EUR' => 'EUROLUX',
+        'EUD' => 'Eudora',
         'E9'  => 'Evercoss',
         'EV'  => 'Evertek',
         'EVE' => 'Everest',
         'EV1' => 'Everex',
+        'EVR' => 'Everis',
+        'EVF' => 'Everfine',
         'E3'  => 'Evolio',
         'EO'  => 'Evolveo',
         '0Q'  => 'Evoo',
         '5U'  => 'EVPAD',
+        'EVV' => 'evvoli',
         'E0'  => 'EvroMedia',
         'XE'  => 'ExMobile',
         '4Z'  => 'Exmart',
@@ -590,6 +643,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'FIT' => 'FITCO',
         'FLM' => 'Filimo',
         'FIL' => 'FILIX',
+        'FIN' => 'FINIX',
         'FL'  => 'Fly',
         'QC'  => 'FLYCAT',
         'FLY' => 'FLYCOAY',
@@ -600,10 +654,13 @@ abstract class AbstractDeviceParser extends AbstractParser
         '0F'  => 'Fourel',
         '44'  => 'Four Mobile',
         'F0'  => 'Fonos',
+        'F0N' => 'FONTEL',
         'F2'  => 'FORME',
+        'FRM' => 'Formovie',
         'F5'  => 'Formuler',
         'FR'  => 'Forstar',
         'RF'  => 'Fortis',
+        'FRT' => 'FortuneShip',
         'FO'  => 'Foxconn',
         'FOD' => 'FoxxD',
         'FJ'  => 'FOODO',
@@ -616,6 +673,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '1F'  => 'FMT',
         'FPT' => 'FPT',
         'FG'  => 'Fuego',
+        'FUJ' => 'FUJICOM',
         'FU'  => 'Fujitsu',
         '4F'  => 'Funai',
         '5J'  => 'Fusion5',
@@ -628,6 +686,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GFO' => 'Gfone',
         'GTM' => 'GTMEDIA',
         'GTX' => 'GTX',
+        'GDL' => 'GDL',
         '0G'  => 'GFive',
         'GM'  => 'Garmin-Asus',
         'GA'  => 'Gateway',
@@ -640,6 +699,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GD'  => 'Gemini',
         'GN'  => 'General Mobile',
         '2G'  => 'Genesis',
+        'GEP' => 'Geo Phone',
         'G2'  => 'GEOFOX',
         'GE'  => 'Geotel',
         'Q4'  => 'Geotex',
@@ -657,14 +717,18 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GIR' => 'GIRASOLE',
         'G4'  => 'Globex',
         'GLB' => 'Globmall',
+        'GME' => 'GlocalMe',
         '38'  => 'GLONYX',
         'U6'  => 'Glofiish',
+        'GLO' => 'Glory Star',
+        'GNE' => 'GN Electronics',
         'G7'  => 'GoGEN',
         'GC'  => 'GOCLEVER',
         '5G'  => 'Gocomma',
         'GB'  => 'Gol Mobile',
         'GL'  => 'Goly',
         'GOL' => 'GoldMaster',
+        'GOS' => 'GoldStar',
         'GOB' => 'GOLDBERG',
         'GX'  => 'GLX',
         'G5'  => 'Gome',
@@ -673,6 +737,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'G0'  => 'Goophone',
         '6G'  => 'Gooweel',
         'GOO' => 'GOODTEL',
+        'GO1' => 'GOtv',
+        'GPL' => 'G-PLUS',
         '8G'  => 'Gplus',
         'GR'  => 'Gradiente',
         'GRE' => 'Graetz',
@@ -685,9 +751,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'GR1' => 'GroBerwert',
         'GF'  => 'Gretel',
         '82'  => 'Gresso',
+        'GRB' => 'Grünberg',
         'GU'  => 'Grundig',
         'GV'  => 'Gtel',
         'CUO' => 'Guophone',
+        'GVC' => 'GVC Pro',
         'H13' => 'H133',
         '9Z'  => 'H96',
         'HF'  => 'Hafury',
@@ -696,9 +764,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'HA'  => 'Haier',
         'HEC' => 'HEC',
         'XH'  => 'Haipai',
+        'XHU' => 'Haixu',
         'HAN' => 'Handheld',
         'HE'  => 'HannSpree',
         'HNS' => 'Hanseatic',
+        'HA2' => 'Hanson',
         'HK'  => 'Hardkernel',
         'HAR' => 'Harper',
         'HA1' => 'Hartens',
@@ -706,6 +776,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         '8H'  => 'Hamlet',
         'HAM' => 'Hammer',
         'HAT' => 'Hathway',
+        'HAV' => 'HAVIT',
+        'HEM' => 'Hemilton',
         'H6'  => 'Helio',
         'HQ'  => 'HERO',
         'ZH'  => 'Hezire',
@@ -720,6 +792,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'HIK' => 'HiKing',
         'H2'  => 'Highscreen',
         'Q1'  => 'High Q',
+        'HI1' => 'HIGH1ONE',
         'HIG' => 'HiGrace',
         '1H'  => 'Hipstreet',
         'HIR' => 'Hiremco',
@@ -731,23 +804,30 @@ abstract class AbstractDeviceParser extends AbstractParser
         '8X'  => 'Hi Nova',
         'HLL' => 'HLLO',
         'HKC' => 'HKC',
+        'HMD' => 'HMD',
         '8W'  => 'HKPro',
         'HOF' => 'HOFER',
+        'HOC' => 'hoco',
         'H1'  => 'Hoffmann',
         'HOM' => 'Homatics',
         'H0'  => 'Hometech',
         'HLB' => 'HOLLEBERG',
         'HM'  => 'Homtom',
+        'HOP' => 'Hopeland',
         'HZ'  => 'Hoozo',
+        'HOR' => 'Horion',
         'H7'  => 'Horizon',
         '4H'  => 'Horizont',
         'HO'  => 'Hosin',
         'H3'  => 'Hotel',
         'HV'  => 'Hotwav',
         'U8'  => 'Hot Pepper',
+        'HOT' => 'HOTACK',
         'JH'  => 'HOTREALS',
         'HW'  => 'How',
         'WH'  => 'Honeywell',
+        'HON' => 'HongTop',
+        'HOG' => 'HONKUAHG',
         'HP'  => 'HP',
         'HDC' => 'HDC',
         'HT'  => 'HTC',
@@ -756,6 +836,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'HG'  => 'Huavi',
         'HU'  => 'Huawei',
         'HX'  => 'Humax',
+        'HUM' => 'Humanware',
+        'HME' => 'HUMElab',
         'HR'  => 'Hurricane',
         'H5'  => 'Huskee',
         'HUG' => 'Hugerock',
@@ -764,6 +846,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         '7H'  => 'Hyve',
         'HYT' => 'Hytera',
         'HYK' => 'Hykker',
+        'HYA' => 'Hyatta',
+        'IKL' => 'I KALL',
         '3I'  => 'i-Cherry',
         'IJ'  => 'i-Joy',
         'IM'  => 'i-mate',
@@ -779,7 +863,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         'IC'  => 'iDroid',
         'IDI' => 'iDino',
         '6Z'  => 'iData',
+        'IDC' => 'IDC',
         'IG'  => 'iGet',
+        'IHL' => 'iHome Life',
         'IH'  => 'iHunt',
         'IA'  => 'Ikea',
         'IYO' => 'iYou',
@@ -825,6 +911,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'IV'  => 'Inverto',
         '32'  => 'Invens',
         '4I'  => 'Invin',
+        'IFT' => 'iFIT',
         'INA' => 'iNavi',
         'I1'  => 'iOcean',
         'IMU' => 'iMuz',
@@ -853,6 +940,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'IXT' => 'iXTech',
         'IOT' => 'IOTWE',
         'JA'  => 'JAY-Tech',
+        'JAM' => 'Jambo',
         'KJ'  => 'Jiake',
         'JD'  => 'Jedi',
         'JEE' => 'Jeep',
@@ -892,11 +980,13 @@ abstract class AbstractDeviceParser extends AbstractParser
         'KS'  => 'Kempler & Strauss',
         'K3'  => 'Keneksi',
         'KHI' => 'KENSHI',
+        'KNW' => 'KENWOOD',
         'KX'  => 'Kenxinda',
         'KEN' => 'Kenbo',
         'KND' => 'Kendo',
         'KZG' => 'KZG',
         'K1'  => 'Kiano',
+        'KID' => 'kidiby',
         '5W'  => 'Kingbox',
         'KI'  => 'Kingsun',
         'KIS' => 'Kinstone',
@@ -921,6 +1011,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'KR'  => 'Koridy',
         'XK'  => 'Koslam',
         'K2'  => 'KRONO',
+        'KRX' => 'Korax',
         'KE'  => 'Krüger&Matz',
         '5K'  => 'KREZ',
         'WK'  => 'KRIP',
@@ -944,6 +1035,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'LK'  => 'Lark',
         'Z3'  => 'Laurus',
         'LEC' => 'Lectrus',
+        'LAS' => 'Laser',
         'LV'  => 'Lava',
         'LVI' => 'Lville',
         'LC'  => 'LCT',
@@ -980,22 +1072,28 @@ abstract class AbstractDeviceParser extends AbstractParser
         'JJ'  => 'Listo',
         'LNM' => 'LNMBBS',
         'LO'  => 'Loewe',
+        'LNG' => 'LongTV',
         'YL'  => 'Loview',
         'LOV' => 'Lovme',
+        'LGN' => 'LOGAN',
         '1L'  => 'Logic',
         'LH'  => 'Logic Instrument',
         'LM'  => 'Logicom',
         'LOG' => 'Logik',
+        'LGT' => 'Logitech',
         'GY'  => 'LOKMAT',
         'LPX' => 'LPX-G',
         '0L'  => 'Lumigon',
         'LU'  => 'Lumus',
         'LUM' => 'Lumitel',
         'L9'  => 'Luna',
+        'LUO' => 'LUO',
         'LR'  => 'Luxor',
         'LY'  => 'LYF',
         'LL'  => 'Leader Phone',
+        'LTL' => 'LYOTECH LABS',
         'QL'  => 'LT Mobile',
+        'LW1' => 'LW',
         'MQ'  => 'M.T.T.',
         'MN'  => 'M4tel',
         'XM'  => 'Macoox',
@@ -1003,6 +1101,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'MJ'  => 'Majestic',
         'FQ'  => 'Mafe',
         'MAG' => 'MAG',
+        'MA2' => 'MAGCH',
         '6Y'  => 'Magicsee',
         '23'  => 'Magnus',
         'NH'  => 'Manhattan',
@@ -1040,13 +1139,15 @@ abstract class AbstractDeviceParser extends AbstractParser
         'M3'  => 'Mecer',
         'M3M' => 'M3 Mobile',
         '0M'  => 'Mecool',
+        'MEC' => 'MECHEN',
         'MEM' => 'MeMobile',
         'MC'  => 'Mediacom',
-        'MK'  => 'MediaTek',
         'MD'  => 'Medion',
         'M2'  => 'MEEG',
         'MEG' => 'MEGA VISION',
+        'MCA' => 'Megacable',
         'MP'  => 'MegaFon',
+        'MGX' => 'MEGAMAX',
         'X0'  => 'mPhone',
         '3M'  => 'Meitu',
         'M1'  => 'Meizu',
@@ -1055,14 +1156,17 @@ abstract class AbstractDeviceParser extends AbstractParser
         'ME'  => 'Metz',
         'MEO' => 'MEO',
         'MX'  => 'MEU',
+        'MES' => 'MESWAO',
         'MI'  => 'MicroMax',
         'MIP' => 'mipo',
         'MS'  => 'Microsoft',
         '6Q'  => 'Microtech',
+        'MIG' => 'Mightier',
         '1X'  => 'Minix',
         'OM'  => 'Mintt',
         'MIN' => 'Mint',
         'MO'  => 'Mio',
+        'MOD' => 'Moondrop',
         'X7'  => 'Mione',
         'M7'  => 'Miray',
         'MIT' => 'Mitchell & Brown',
@@ -1088,8 +1192,10 @@ abstract class AbstractDeviceParser extends AbstractParser
         'MOB' => 'Mobell',
         'MVO' => 'Mobvoi',
         'M4'  => 'Modecom',
+        'MEP' => 'Mode Mobile',
         'MF'  => 'Mofut',
         'MR'  => 'Motorola',
+        'MTS' => 'Motorola Solutions',
         'MIV' => 'Motiv',
         'MV'  => 'Movic',
         'MOV' => 'Movitel',
@@ -1103,10 +1209,13 @@ abstract class AbstractDeviceParser extends AbstractParser
         'N4'  => 'MTN',
         '72'  => 'M-Tech',
         '9H'  => 'M-Horse',
+        'MKP' => 'M-KOPA',
+        'MLB' => 'multibox',
         '1R'  => 'Multilaser',
         'MPS' => 'MultiPOS',
         '1M'  => 'MYFON',
-        'MY'  => 'MyPhone',
+        'MY1' => 'myPhone (PL)',
+        'MY'  => 'MyPhone (PH)',
         '51'  => 'Myros',
         'M8'  => 'Myria',
         '6M'  => 'Mystery',
@@ -1140,6 +1249,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '7Q'  => 'Neon IQ',
         '8F'  => 'Neolix',
         'NET' => 'NetBox',
+        'NWT' => 'NETWIT',
         'NA'  => 'Netgear',
         'NEM' => 'Netmak',
         'NU'  => 'NeuImage',
@@ -1152,6 +1262,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'ND'  => 'Newsday',
         'HB'  => 'New Balance',
         'BRI' => 'New Bridge',
+        'NEW' => 'Newal',
         'XB'  => 'NEXBOX',
         'NX'  => 'Nexian',
         '7X'  => 'Nexa',
@@ -1167,8 +1278,10 @@ abstract class AbstractDeviceParser extends AbstractParser
         'NZ'  => 'NG Optics',
         'NZP' => 'NGpon',
         'NN'  => 'Nikon',
+        'NIL' => 'NILAIT',
         'NI'  => 'Nintendo',
         'NIN' => 'NINETEC',
+        'NI1' => 'NINETOLOGY',
         'N5'  => 'NOA',
         'N1'  => 'Noain',
         'N6'  => 'Nobby',
@@ -1185,9 +1298,10 @@ abstract class AbstractDeviceParser extends AbstractParser
         '2N'  => 'Nomu',
         '6H'  => 'Noontec',
         'NR'  => 'Nordmende',
+        'NRD' => 'Nordfrost',
         'NOR' => 'NORMANDE',
         '7N'  => 'NorthTech',
-        'NOT' => 'Nothing Phone',
+        'NOT' => 'Nothing',
         '5N'  => 'Nos',
         'NO'  => 'Nous',
         'NQ'  => 'Novex',
@@ -1208,7 +1322,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'OQ'  => 'Meta',
         'O1'  => 'Odys',
         'ODP' => 'Odotpad',
-        'O9'  => 'Ok',
+        'O9'  => 'ok.',
+        'OKA' => 'Okapi',
         'OA'  => 'Okapia',
         'OKI' => 'Oking',
         'OLA' => 'Olax',
@@ -1237,6 +1352,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'OPT' => 'Optoma',
         'OPH' => 'Ophone',
         'OR'  => 'Orange',
+        'ORP' => 'Orange Pi',
         'ORA' => 'Orava',
         'O5'  => 'Orbic',
         'Y6'  => 'Orbita',
@@ -1246,6 +1362,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'OTT' => 'OTTO',
         'OK'  => 'Ouki',
         '0O'  => 'OINOM',
+        'OIL' => 'Oilsky',
         'QK'  => 'OKWU',
         'QQ'  => 'OMIX',
         '56'  => 'OKSI',
@@ -1256,6 +1373,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '30'  => 'Ovvi',
         'O2'  => 'Owwo',
         'OSC' => 'OSCAL',
+        'OXT' => 'OX TAB',
         'OY'  => 'Oysters',
         'QF'  => 'OYSIN',
         'O6'  => 'Oyyu',
@@ -1275,6 +1393,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'PND' => 'Panodic',
         'PA1' => 'Panoramic',
         'PLT' => 'Platoon',
+        'PLD' => 'PLDT',
         '94'  => 'Packard Bell',
         'H9'  => 'Parrot Mobile',
         'PAR' => 'Partner Mobile',
@@ -1300,6 +1419,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '8P'  => 'Pixelphone',
         '9O'  => 'Pixela',
         'PX'  => 'Pixus',
+        'PIX' => 'PIXPRO',
         'QP'  => 'Pico',
         'PIR' => 'PIRANHA',
         'PIN' => 'PINE',
@@ -1313,6 +1433,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '0P'  => 'POCO',
         'FH'  => 'Point Mobile',
         'PV'  => 'Point of View',
+        'PVB' => 'PVBox',
         'PL'  => 'Polaroid',
         'Q6'  => 'Polar',
         '97'  => 'PolarLine',
@@ -1324,6 +1445,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'PS'  => 'Positivo',
         '3P'  => 'Positivo BGH',
         '3F'  => 'Porsche',
+        'PRT' => 'Portfolio',
         'P3'  => 'PPTV',
         'FP'  => 'Premio',
         'PR1' => 'Premier',
@@ -1333,6 +1455,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '6P'  => 'Primux',
         '2P'  => 'Prixton',
         'PRI' => 'Pritom',
+        'PRP' => 'PRISM+',
         'PF'  => 'PROFiLO',
         'P6'  => 'Proline',
         '5O'  => 'Prology',
@@ -1365,6 +1488,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'WJ'  => 'Qware',
         'QWT' => 'QWATT',
         'R2'  => 'R-TV',
+        'R3D' => 'R3Di',
         'RA'  => 'Ramos',
         '0R'  => 'Raspberry',
         'R9'  => 'Ravoz',
@@ -1372,12 +1496,16 @@ abstract class AbstractDeviceParser extends AbstractParser
         '95'  => 'Rakuten',
         'RAY' => 'Raylandz',
         'RC'  => 'RCA Tablets',
+        'RCT' => 'RCT',
         '2R'  => 'Reach',
+        'RLX' => 'Realix',
         'REL' => 'RelNAT',
+        'RE4' => 'Relndoo',
         'RB'  => 'Readboy',
         'RE'  => 'Realme',
         'RE1' => 'Redbean',
         'R8'  => 'RED',
+        'RDX' => 'RED-X',
         'REW' => 'Redway',
         '6F'  => 'Redfox',
         'RE2' => 'RedLine',
@@ -1388,10 +1516,14 @@ abstract class AbstractDeviceParser extends AbstractParser
         'REV' => 'Revomovil',
         '8R'  => 'Retroid Pocket',
         'REN' => 'Renova',
+        'RE3' => 'RENSO',
+        'REP' => 'rephone',
+        'RHI' => 'Rhino',
         'RIC' => 'Ricoh',
         'RI'  => 'Rikomagic',
         'RM'  => 'RIM',
         'RN'  => 'Rinno',
+        'RNB' => 'Ringing Bells',
         'RX'  => 'Ritmix',
         'R7'  => 'Ritzviva',
         'RV'  => 'Riviera',
@@ -1399,7 +1531,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         'RIZ' => 'Rizzen',
         'RR'  => 'Roadrover',
         'QR'  => 'ROADMAX',
+        'ROH' => 'ROCH',
         'ROC' => 'Roam Cat',
+        'ROT' => 'Rocket',
         'R1'  => 'Rokit',
         'ROI' => 'ROiK',
         'RK'  => 'Roku',
@@ -1410,6 +1544,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'RQ'  => 'RoyQueen',
         'RJ'  => 'Royole',
         'RT'  => 'RT Project',
+        'RTK' => 'RTK',
         'RG'  => 'RugGear',
         'RUG' => 'Ruggex',
         'RUT' => 'RuggeTech',
@@ -1424,6 +1559,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         '89'  => 'Seatel',
         'SEW' => 'Sewoo',
         'SE1' => 'SEEWO',
+        'SEN' => 'SENNA',
+        'SER' => 'SERVO',
         'Y7'  => 'Saiet',
         'SLF' => 'SAILF',
         'X1'  => 'Safaricom',
@@ -1441,9 +1578,12 @@ abstract class AbstractDeviceParser extends AbstractParser
         'SY'  => 'Sanyo',
         'SAN' => 'SANY',
         'S9'  => 'Savio',
-        'Y4'  => 'SCBC',
+        'Y4'  => 'TCL SCBC',
+        'SCH' => 'SCHAUB LORENZ',
         'CZ'  => 'Schneider',
+        'SHO' => 'SCHONTECH',
         'SCO' => 'Scosmos',
+        'SC1' => 'Scoole',
         'ZG'  => 'Schok',
         'G8'  => 'SEG',
         'SEX' => 'SEHMAX',
@@ -1479,7 +1619,9 @@ abstract class AbstractDeviceParser extends AbstractParser
         '98'  => 'Simply',
         'SIM' => 'simfer',
         '52'  => 'Singtech',
+        'SIN' => 'SINGER',
         '31'  => 'Siragon',
+        'SIS' => 'Siswoo',
         '83'  => 'Sirin Labs',
         '5Z'  => 'SK Broadband',
         'GK'  => 'SKG',
@@ -1493,6 +1635,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '19'  => 'Smailo',
         'SR'  => 'Smart Electronic',
         'SMA' => 'Smart Kassel',
+        'STE' => 'Smart Tech',
         '49'  => 'Smart',
         '47'  => 'SmartBook',
         '3B'  => 'Smartab',
@@ -1500,6 +1643,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'SM1' => 'Smartex',
         'SC'  => 'Smartfren',
         'S7'  => 'Smartisan',
+        'SMU' => 'SMUX',
+        'SMT' => 'SMT Telecom',
         'JR'  => 'Sylvania',
         'SYH' => 'SYH',
         '3Y'  => 'Smarty',
@@ -1522,6 +1667,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '77'  => 'SONOS',
         '68'  => 'Soho Style',
         'SOB' => 'SobieTech',
+        'SOW' => 'SOWLY',
         'PK'  => 'Spark',
         'SPX' => 'Sparx',
         'FS'  => 'SPC',
@@ -1545,9 +1691,12 @@ abstract class AbstractDeviceParser extends AbstractParser
         '71'  => 'StrawBerry',
         '96'  => 'STRONG',
         '69'  => 'Stylo',
+        'STI' => 'Stilevs',
         '9S'  => 'Sugar',
         'SUR' => 'Surge',
+        'SUF' => 'Surfans',
         '06'  => 'Subor',
+        'SUT' => 'SULPICE TV',
         'SZ'  => 'Sumvision',
         '0H'  => 'Sunstech',
         'S3'  => 'SunVan',
@@ -1555,10 +1704,12 @@ abstract class AbstractDeviceParser extends AbstractParser
         '5Y'  => 'Sunny',
         'W8'  => 'SUNWIND',
         'SBX' => 'SuperBOX',
+        'SBM' => 'Supermax',
         'SBR' => 'Sber',
         'SGE' => 'Super General',
         'SU'  => 'SuperSonic',
         '79'  => 'SuperTab',
+        'STV' => 'SuperTV',
         'S5'  => 'Supra',
         'SUP' => 'Supraim',
         'ZS'  => 'Suzuki',
@@ -1568,6 +1719,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'SWI' => 'Switel',
         'SS'  => 'SWISSMOBILITY',
         '1W'  => 'Swisstone',
+        'SWO' => 'SWOFY',
         'SSK' => 'SSKY',
         'SYC' => 'Syco',
         'SM'  => 'Symphony',
@@ -1582,6 +1734,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'U5'  => 'Taiga System',
         'TAL' => 'Talius',
         '7G'  => 'TAG Tech',
+        'TLB' => 'TALBERG',
         'TAU' => 'TAUBE',
         'T5'  => 'TB Touch',
         'TC'  => 'TCL',
@@ -1594,6 +1747,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TX'  => 'TechniSat',
         'TT'  => 'TechnoTrend',
         'TTS' => 'TECHNOSAT',
+        'TM1' => 'Temigereev',
         'TP'  => 'TechPad',
         'TPS' => 'TPS',
         '9E'  => 'Techwood',
@@ -1622,6 +1776,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TZ'  => 'teXet',
         '29'  => 'Teknosa',
         'JZ'  => 'TJC',
+        'TJD' => 'TJD',
         'JC'  => 'TENPLUS',
         'T4'  => 'ThL',
         'TN'  => 'Thomson',
@@ -1635,13 +1790,16 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TF'  => 'Tinmo',
         'TH'  => 'TiPhone',
         'YV'  => 'TiVo',
+        'TIV' => 'Tivax',
         'TIB' => 'Tibuta',
         'Y3'  => 'TOKYO',
         'TOX' => 'TOX',
         'T1'  => 'Tolino',
         '0T'  => 'Tone',
         'TY'  => 'Tooky',
+        'TYD' => 'TYD',
         'TOO' => 'TOOGO',
+        'TPT' => 'Top-Tech',
         'T9'  => 'Top House',
         'DK'  => 'Topelotek',
         '42'  => 'Topway',
@@ -1651,6 +1809,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TO2' => 'TOPSHOWS',
         '7T'  => 'Torex',
         'TOR' => 'Torque',
+        'TRN' => 'TORNADO',
         '6O'  => 'TOSCIDO',
         'TO1' => 'Topsion',
         'TS'  => 'Toshiba',
@@ -1662,6 +1821,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'TRI' => 'TriaPlay',
         'TJ'  => 'Trifone',
         'Q5'  => 'Trident',
+        'TRB' => 'Trimble',
         '4T'  => 'Tronsmart',
         '11'  => 'True',
         'JT'  => 'True Slim',
@@ -1678,8 +1838,10 @@ abstract class AbstractDeviceParser extends AbstractParser
         'UR'  => 'Turkcell',
         '4U'  => 'TuCEL',
         'TUV' => 'Tuvio',
+        'TUC' => 'TUCSON',
         '2U'  => 'Türk Telekom',
         'TV'  => 'TVC',
+        'TVP' => 'TV+',
         'TW'  => 'TWM',
         'Z1'  => 'TWZ',
         '6T'  => 'Twoe',
@@ -1694,6 +1856,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'UL'  => 'Ulefone',
         'UA'  => 'Umax',
         'UM'  => 'UMIDIGI',
+        'UM2' => 'Umiio',
         'UNT' => 'Unitech',
         'UZ'  => 'Unihertz',
         '3Z'  => 'UZ Mobile',
@@ -1703,8 +1866,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'UNI' => 'Unistrong',
         'U2'  => 'UNIWA',
         'UND' => 'Uniden',
+        'UNE' => 'UNITED',
+        'UGR' => 'United Group',
         'UO'  => 'Unnecto',
         'UNN' => 'Unnion Technologies',
+        'UNP' => 'UnoPhone',
         'UU'  => 'Unonu',
         'UN'  => 'Unowhy',
         'UY'  => 'UNNO',
@@ -1722,10 +1888,12 @@ abstract class AbstractDeviceParser extends AbstractParser
         'VP'  => 'Vargo',
         'VC'  => 'Vankyo',
         'VAL' => 'VALEM',
+        'VA2' => 'VALE',
         'VAT' => 'VALTECH',
         'VAN' => 'VANGUARD',
         'VAW' => 'VANWIN',
         'VB'  => 'VC',
+        'VEI' => 'Veidoo',
         'VN'  => 'Venso',
         'VNP' => 'VNPT Technology',
         'VEN' => 'Venstar',
@@ -1751,6 +1919,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'VD'  => 'Videocon',
         'VW'  => 'Videoweb',
         'VS'  => 'ViewSonic',
+        'VIE' => 'Viendo',
+        'VIK' => 'VIKUSHA',
         'V7'  => 'Vinga',
         'V3'  => 'Vinsoc',
         'XD'  => 'Vinabox',
@@ -1763,6 +1933,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '8V'  => 'Viumee',
         'V5'  => 'Vivax',
         'VIV' => 'VIVIMAGE',
+        'VI2' => 'VIVIBright',
         'VV'  => 'Vivo',
         '6V'  => 'VIWA',
         'VII' => 'VIIPOO',
@@ -1771,8 +1942,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'VIZ' => 'Vizmo',
         'VIT' => 'Vityaz',
         '9V'  => 'Vision Touch',
+        'VIS' => 'Vision Technology',
+        'VST' => 'Visitech',
         'VIL' => 'Visual Land',
         'VI1' => 'VILLAON',
+        'VIM' => 'VIMOQ',
         'VK'  => 'VK Mobile',
         'JM'  => 'v-mobile',
         'VHO' => 'V-HOPE',
@@ -1789,6 +1963,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '2V'  => 'Vorke',
         '8U'  => 'Vorcom',
         'JW'  => 'Vortex',
+        'VRX' => 'VORTEX (RO)',
         'VOR' => 'Vormor',
         'V1'  => 'Voto',
         'Z7'  => 'VOX',
@@ -1809,6 +1984,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'WA'  => 'Walton',
         'WAF' => 'WAF',
         'WAO' => 'W&O',
+        'WLT' => 'Waltham',
         'WAL' => 'Waltter',
         'WAI' => 'Wainyok',
         'WHI' => 'White Mobile',
@@ -1816,9 +1992,11 @@ abstract class AbstractDeviceParser extends AbstractParser
         'WBL' => 'We. by Loewe.',
         'WCP' => 'WeChip',
         'WM'  => 'Weimei',
+        'WM1' => 'Weiimi',
         'WE'  => 'WellcoM',
         'W6'  => 'WELLINGTON',
         'WD'  => 'Western Digital',
+        'WST' => 'Weston',
         'WT'  => 'Westpoint',
         'WAN' => 'Wanmukang',
         'WA1' => 'WANSA',
@@ -1830,6 +2008,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'W2'  => 'Wigor',
         'WI'  => 'Wiko',
         'WF'  => 'Wileyfox',
+        'WLR' => 'WildRed',
         'WS'  => 'Winds',
         'WN'  => 'Wink',
         '9W'  => 'Winmax',
@@ -1848,6 +2027,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'W1'  => 'Woo',
         'WR'  => 'Wortmann',
         'WX'  => 'Woxter',
+        'WOZ' => 'WOZIFAN',
         'XQ'  => 'X-AGE',
         'XEL' => 'XElectron',
         'X3'  => 'X-BO',
@@ -1868,6 +2048,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         'XN'  => 'Xion',
         'XO'  => 'Xolo',
         'XR'  => 'Xoro',
+        'XPP' => 'XPPen',
+        'XRL' => 'XREAL',
         'XS'  => 'Xshitou',
         'XSM' => 'Xsmart',
         '4X'  => 'Xtouch',
@@ -1904,6 +2086,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         '0Z'  => 'Zatec',
         '2Z'  => 'Zaith',
         'ZAM' => 'Zamolxe',
+        'ZZB' => 'ZZB',
         'ZEA' => 'Zealot',
         'PZ'  => 'Zebra',
         'ZE1' => 'Zeblaze',
@@ -1915,6 +2098,7 @@ abstract class AbstractDeviceParser extends AbstractParser
         'ZF'  => 'Zfiner',
         'ZI'  => 'Zidoo',
         'FZ'  => 'ZIFRO',
+        'ZIF' => 'ZIFFLER',
         'ZX'  => 'Ziox',
         'ZIK' => 'ZIK',
         'ZKI' => 'Z-Kai',
@@ -1939,6 +2123,21 @@ abstract class AbstractDeviceParser extends AbstractParser
         'XX'  => 'Unknown',
     ];
 
+    /**
+     * Mapping formFactor types to parser device types
+     * (not sort array the array priority result device type)
+     * @var array
+     */
+    protected static $clientHintFormFactorsMapping = [
+        'automotive' => self::DEVICE_TYPE_CAR_BROWSER,
+        'xr'         => self::DEVICE_TYPE_WEARABLE,
+        'watch'      => self::DEVICE_TYPE_WEARABLE,
+        'mobile'     => self::DEVICE_TYPE_SMARTPHONE,
+        'tablet'     => self::DEVICE_TYPE_TABLET,
+        'desktop'    => self::DEVICE_TYPE_DESKTOP,
+        'eink'       => self::DEVICE_TYPE_TABLET,
+    ];
+
     /**
      * Returns the device type represented by one of the DEVICE_TYPE_* constants
      *
@@ -2058,14 +2257,10 @@ abstract class AbstractDeviceParser extends AbstractParser
         $resultClientHint = $this->parseClientHints();
         $deviceModel      = $resultClientHint['model'] ?? '';
 
-        // is freeze user-agent then restoring the original UA for the device definition
-        if ('' !== $deviceModel && \preg_match('~Android 10[.\d]*; K(?: Build/|[;)])~i', $this->userAgent)) {
-            $osVersion = $this->clientHints ? $this->clientHints->getOperatingSystemVersion() : '';
-            $this->setUserAgent((string) \preg_replace(
-                '(Android 10[.\d]*; K)',
-                \sprintf('Android %s; %s', '' !== $osVersion ? $osVersion : '10', $deviceModel),
-                $this->userAgent
-            ));
+        $this->restoreUserAgentFromClientHints();
+
+        if ('' === $deviceModel && $this->hasUserAgentClientHintsFragment()) {
+            return $this->getResult();
         }
 
         if ('' === $deviceModel && $this->hasDesktopFragment()) {
@@ -2084,6 +2279,8 @@ abstract class AbstractDeviceParser extends AbstractParser
         }
 
         if (empty($matches)) {
+            $this->deviceType = $resultClientHint['deviceType'] ?? null;
+
             return $resultClientHint;
         }
 
@@ -2166,8 +2363,19 @@ abstract class AbstractDeviceParser extends AbstractParser
     protected function parseClientHints(): ?array
     {
         if ($this->clientHints && $this->clientHints->getModel()) {
+            $detectedDeviceType = null;
+            $formFactors        = $this->clientHints->getFormFactors();
+
+            foreach (self::$clientHintFormFactorsMapping as $formFactor => $deviceType) {
+                if (\in_array($formFactor, $formFactors)) {
+                    $detectedDeviceType = $deviceType;
+
+                    break;
+                }
+            }
+
             return [
-                'deviceType' => null,
+                'deviceType' => $detectedDeviceType,
                 'model'      => $this->clientHints->getModel(),
                 'brand'      => '',
             ];
@@ -2176,24 +2384,6 @@ abstract class AbstractDeviceParser extends AbstractParser
         return null;
     }
 
-    /**
-     * Returns if the parsed UA contains the 'Windows NT;' or 'X11; Linux x86_64' fragments
-     *
-     * @return bool
-     */
-    protected function hasDesktopFragment(): bool
-    {
-        $regexExcludeDesktopFragment = \implode('|', [
-            'CE-HTML',
-            ' Mozilla/|Andr[o0]id|Tablet|Mobile|iPhone|Windows Phone|ricoh|OculusBrowser',
-            'PicoBrowser|Lenovo|compatible; MSIE|Trident/|Tesla/|XBOX|FBMD/|ARM; ?([^)]+)',
-        ]);
-
-        return
-            $this->matchUserAgent('(?:Windows (?:NT|IoT)|X11; Linux x86_64)') &&
-            !$this->matchUserAgent($regexExcludeDesktopFragment);
-    }
-
     /**
      * Resets the stored values
      */
