@@ -47,15 +47,19 @@ class OperatingSystem extends AbstractParser
         'AMZ' => 'Amazon Linux',
         'AMG' => 'AmigaOS',
         'ARM' => 'Armadillo OS',
+        'ARO' => 'AROS',
         'ATV' => 'tvOS',
         'ARL' => 'Arch Linux',
         'AOS' => 'AOSC OS',
         'ASP' => 'ASPLinux',
+        'AZU' => 'Azure Linux',
         'BTR' => 'BackTrack',
         'SBA' => 'Bada',
+        'BYI' => 'Baidu Yi',
         'BEO' => 'BeOS',
         'BLB' => 'BlackBerry OS',
         'QNX' => 'BlackBerry Tablet OS',
+        'PAN' => 'blackPanther OS',
         'BOS' => 'Bliss OS',
         'BMP' => 'Brew',
         'BSN' => 'BrightSignOS',
@@ -67,6 +71,7 @@ class OperatingSystem extends AbstractParser
         'COS' => 'Chrome OS',
         'CRS' => 'Chromium OS',
         'CHN' => 'China OS',
+        'COL' => 'Coolita OS',
         'CYN' => 'CyanogenMod',
         'DEB' => 'Debian',
         'DEE' => 'Deepin',
@@ -85,6 +90,9 @@ class OperatingSystem extends AbstractParser
         'FYD' => 'FydeOS',
         'FUC' => 'Fuchsia',
         'GNT' => 'Gentoo',
+        'GNX' => 'GENIX',
+        'GEO' => 'GEOS',
+        'GNS' => 'gNewSense',
         'GRI' => 'GridOS',
         'GTV' => 'Google TV',
         'HPX' => 'HP-UX',
@@ -96,13 +104,16 @@ class OperatingSystem extends AbstractParser
         'IRI' => 'IRIX',
         'INF' => 'Inferno',
         'JME' => 'Java ME',
+        'JOL' => 'Joli OS',
         'KOS' => 'KaiOS',
         'KAL' => 'Kali',
         'KAN' => 'Kanotix',
+        'KIN' => 'KIN OS',
         'KNO' => 'Knoppix',
         'KTV' => 'KreaTV',
         'KBT' => 'Kubuntu',
         'LIN' => 'GNU/Linux',
+        'LEA' => 'LeafOS',
         'LND' => 'LindowsOS',
         'LNS' => 'Linspire',
         'LEN' => 'Lineage OS',
@@ -117,20 +128,25 @@ class OperatingSystem extends AbstractParser
         'MAG' => 'Mageia',
         'MDR' => 'Mandriva',
         'SMG' => 'MeeGo',
+        'MET' => 'Meta Horizon',
         'MCD' => 'MocorDroid',
         'MON' => 'moonOS',
+        'EZX' => 'Motorola EZX',
         'MIN' => 'Mint',
         'MLD' => 'MildWild',
         'MOR' => 'MorphOS',
         'NBS' => 'NetBSD',
         'MTK' => 'MTK / Nucleus',
         'MRE' => 'MRE',
+        'NXT' => 'NeXTSTEP',
+        'NWS' => 'NEWS-OS',
         'WII' => 'Nintendo',
         'NDS' => 'Nintendo Mobile',
         'NOV' => 'Nova',
         'OS2' => 'OS/2',
         'T64' => 'OSF1',
         'OBS' => 'OpenBSD',
+        'OVS' => 'OpenVMS',
         'OVZ' => 'OpenVZ',
         'OWR' => 'OpenWrt',
         'OTV' => 'Opera TV',
@@ -143,13 +159,16 @@ class OperatingSystem extends AbstractParser
         'PSP' => 'PlayStation Portable',
         'PS3' => 'PlayStation',
         'PVE' => 'Proxmox VE',
+        'PUF' => 'Puffin OS',
         'PUR' => 'PureOS',
+        'QTP' => 'Qtopia',
         'PIO' => 'Raspberry Pi OS',
         'RAS' => 'Raspbian',
         'RHT' => 'Red Hat',
         'RST' => 'Red Star',
         'RED' => 'RedOS',
         'REV' => 'Revenge OS',
+        'RIS' => 'risingOS',
         'ROS' => 'RISC OS',
         'ROC' => 'Rocky Linux',
         'ROK' => 'Roku OS',
@@ -159,6 +178,7 @@ class OperatingSystem extends AbstractParser
         'RRS' => 'Resurrection Remix OS',
         'REX' => 'REX',
         'RZD' => 'RazoDroiD',
+        'RXT' => 'RTOS & Next',
         'SAB' => 'Sabayon',
         'SSE' => 'SUSE',
         'SAF' => 'Sailfish OS',
@@ -168,6 +188,7 @@ class OperatingSystem extends AbstractParser
         'SIR' => 'Sirin OS',
         'SLW' => 'Slackware',
         'SOS' => 'Solaris',
+        'SBL' => 'Star-Blade OS',
         'SYL' => 'Syllable',
         'SYM' => 'Symbian',
         'SYS' => 'Symbian OS',
@@ -179,9 +200,12 @@ class OperatingSystem extends AbstractParser
         'TIZ' => 'Tizen',
         'TIV' => 'TiVo OS',
         'TOS' => 'TmaxOS',
+        'TUR' => 'Turbolinux',
         'UBT' => 'Ubuntu',
+        'ULT' => 'ULTRIX',
         'UOS' => 'UOS',
         'VID' => 'VIDAA',
+        'VIZ' => 'ViziOS',
         'WAS' => 'watchOS',
         'WER' => 'Wear OS',
         'WTV' => 'WebTV',
@@ -192,6 +216,7 @@ class OperatingSystem extends AbstractParser
         'WMO' => 'Windows Mobile',
         'WPH' => 'Windows Phone',
         'WRT' => 'Windows RT',
+        'WPO' => 'WoPhone',
         'XBX' => 'Xbox',
         'XBT' => 'Xubuntu',
         'YNS' => 'YunOS',
@@ -212,9 +237,9 @@ class OperatingSystem extends AbstractParser
         'Android'               => [
             'AND', 'CYN', 'FIR', 'REM', 'RZD', 'MLD', 'MCD', 'YNS', 'GRI', 'HAR',
             'ADR', 'CLR', 'BOS', 'REV', 'LEN', 'SIR', 'RRS', 'WER', 'PIC', 'ARM',
-            'HEL',
+            'HEL', 'BYI', 'RIS', 'PUF', 'LEA', 'MET',
         ],
-        'AmigaOS'               => ['AMG', 'MOR'],
+        'AmigaOS'               => ['AMG', 'MOR', 'ARO'],
         'BlackBerry'            => ['BLB', 'QNX'],
         'Brew'                  => ['BMP'],
         'BeOS'                  => ['BEO', 'HAI'],
@@ -233,20 +258,22 @@ class OperatingSystem extends AbstractParser
             'FOR', 'MON', 'KAN', 'ZEN', 'LND', 'LNS', 'CHN', 'AMZ', 'TEN', 'CST',
             'NOV', 'ROU', 'ZOR', 'RED', 'KAL', 'ORA', 'VID', 'TIV', 'BSN', 'RAS',
             'UOS', 'PIO', 'FRI', 'LIR', 'WEB', 'SER', 'ASP', 'AOS', 'LOO', 'EUL',
-            'SCI', 'ALP', 'CLO', 'ROC', 'OVZ', 'PVE', 'RST',
+            'SCI', 'ALP', 'CLO', 'ROC', 'OVZ', 'PVE', 'RST', 'EZX', 'GNS', 'JOL',
+            'TUR', 'QTP', 'WPO', 'PAN', 'VIZ', 'AZU', 'COL',
         ],
         'Mac'                   => ['MAC'],
         'Mobile Gaming Console' => ['PSP', 'NDS', 'XBX'],
-        'Real-time OS'          => ['MTK', 'TDX', 'MRE', 'JME', 'REX'],
-        'Other Mobile'          => ['WOS', 'POS', 'SBA', 'TIZ', 'SMG', 'MAE', 'LUN'],
+        'OpenVMS'               => ['OVS'],
+        'Real-time OS'          => ['MTK', 'TDX', 'MRE', 'JME', 'REX', 'RXT'],
+        'Other Mobile'          => ['WOS', 'POS', 'SBA', 'TIZ', 'SMG', 'MAE', 'LUN', 'GEO'],
         'Symbian'               => ['SYM', 'SYS', 'SY3', 'S60', 'S40'],
         'Unix'                  => [
             'SOS', 'AIX', 'HPX', 'BSD', 'NBS', 'OBS', 'DFB', 'SYL', 'IRI', 'T64',
-            'INF', 'ELE',
+            'INF', 'ELE', 'GNX', 'ULT', 'NWS', 'NXT', 'SBL',
         ],
         'WebTV'                 => ['WTV'],
         'Windows'               => ['WIN'],
-        'Windows Mobile'        => ['WPH', 'WMO', 'WCE', 'WRT', 'WIO'],
+        'Windows Mobile'        => ['WPH', 'WMO', 'WCE', 'WRT', 'WIO', 'KIN'],
         'Other Smart TV'        => ['WHS'],
     ];
 
@@ -295,6 +322,7 @@ class OperatingSystem extends AbstractParser
      * @var array
      */
     private $lineageOsVersionMapping = [
+        '15'    => '22',
         '14'    => '21',
         '13'    => '20.0',
         '12.1'  => '19.1',
@@ -368,6 +396,8 @@ class OperatingSystem extends AbstractParser
      */
     public function parse(): ?array
     {
+        $this->restoreUserAgentFromClientHints();
+
         $osFromClientHints = $this->parseOsFromClientHints();
         $osFromUserAgent   = $this->parseOsFromUserAgent();
 
@@ -382,12 +412,17 @@ class OperatingSystem extends AbstractParser
                 $version = $osFromUserAgent['version'];
             }
 
+            // On Windows, version 0.0.0 can be either 7, 8 or 8.1
+            if ('Windows' === $name && '0.0.0' === $version) {
+                $version = ('10' === $osFromUserAgent['version']) ? '' : $osFromUserAgent['version'];
+            }
+
             // If the OS name detected from client hints matches the OS family from user agent
             // but the os name is another, we use the one from user agent, as it might be more detailed
             if (self::getOsFamily($osFromUserAgent['name']) === $name && $osFromUserAgent['name'] !== $name) {
                 $name = $osFromUserAgent['name'];
 
-                if ('HarmonyOS' === $name) {
+                if ('LeafOS' === $name || 'HarmonyOS' === $name) {
                     $version = '';
                 }
 
@@ -395,11 +430,11 @@ class OperatingSystem extends AbstractParser
                     $version = $osFromUserAgent['version'];
                 }
 
-                if ('Fire OS' === $osFromUserAgent['name']) {
-                        $majorVersion = (int) (\explode('.', $version, 1)[0] ?? '0');
+                if ('Fire OS' === $name && !empty($osFromClientHints['version'])) {
+                    $majorVersion = (int) (\explode('.', $version, 1)[0] ?? '0');
 
-                        $version = $this->fireOsVersionMapping[$version]
-                            ?? $this->fireOsVersionMapping[$majorVersion] ?? '';
+                    $version = $this->fireOsVersionMapping[$version]
+                        ?? $this->fireOsVersionMapping[$majorVersion] ?? '';
                 }
             }
 
@@ -413,6 +448,19 @@ class OperatingSystem extends AbstractParser
                 $name  = $osFromUserAgent['name'];
                 $short = $osFromUserAgent['short_name'];
             }
+
+            // Chrome OS is in some cases reported as Android in client hints
+            if ('Android' === $name && 'Chrome OS' === $osFromUserAgent['name']) {
+                $name    = $osFromUserAgent['name'];
+                $version = '';
+                $short   = $osFromUserAgent['short_name'];
+            }
+
+            // Meta Horizon is reported as Linux in client hints
+            if ('GNU/Linux' === $name && 'Meta Horizon' === $osFromUserAgent['name']) {
+                $name  = $osFromUserAgent['name'];
+                $short = $osFromUserAgent['short_name'];
+            }
         } elseif (!empty($osFromUserAgent['name'])) {
             $name    = $osFromUserAgent['name'];
             $version = $osFromUserAgent['version'];
@@ -551,15 +599,20 @@ class OperatingSystem extends AbstractParser
 
             if ('Windows' === $name) {
                 $majorVersion = (int) (\explode('.', $version, 1)[0] ?? '0');
+                $minorVersion = (int) (\explode('.', $version, 2)[1] ?? '0');
 
-                if ($majorVersion > 0 && $majorVersion < 11) {
+                if (0 === $majorVersion) {
+                    $minorVersionMapping = [1 => '7', 2 => '8', 3 => '8.1'];
+                    $version             = $minorVersionMapping[$minorVersion] ?? $version;
+                } elseif ($majorVersion > 0 && $majorVersion < 11) {
                     $version = '10';
                 } elseif ($majorVersion > 10) {
                     $version = '11';
                 }
             }
 
-            if (0 === (int) $version) {
+            // On Windows, version 0.0.0 can be either 7, 8 or 8.1, so we return 0.0.0
+            if ('Windows' !== $name && '0.0.0' !== $version && 0 === (int) $version) {
                 $version = '';
             }
         }
@@ -668,7 +721,7 @@ class OperatingSystem extends AbstractParser
             }
         }
 
-        if ($this->matchUserAgent('arm|.*arm64|aarch64|Apple ?TV|Watch ?OS|Watch1,[12]')) {
+        if ($this->matchUserAgent('arm[ _;)ev]|.*arm$|.*arm64|aarch64|Apple ?TV|Watch ?OS|Watch1,[12]')) {
             return 'ARM';
         }
 
@@ -688,7 +741,7 @@ class OperatingSystem extends AbstractParser
             return 'SPARC64';
         }
 
-        if ($this->matchUserAgent('64-?bit|WOW64|(?:Intel)?x64|WINDOWS_64|win64|amd64|x86_?64')) {
+        if ($this->matchUserAgent('64-?bit|WOW64|(?:Intel)?x64|WINDOWS_64|win64|.*amd64|.*x86_?64')) {
             return 'x64';
         }
 
